@@ -10,16 +10,36 @@ our $client;
 our $count = 1;
 $Data::Dumper::Deparse = 1;
 
+no warnings 'redefine';
+
 my $module;
-our $sessionId = 'f5eec18ebb9bc96352595e2d8ce962e8ecf7af7c9a98cb9a43f9cd181cf4b545';
+our $sessionId =
+  'f5eec18ebb9bc96352595e2d8ce962e8ecf7af7c9a98cb9a43f9cd181cf4b545';
 our $file = "t/sessions/$sessionId";
 
 sub init {
-    $module = shift;
-    use_ok($module);
-    ok( $client = Lemonldap::NG::Handler::PSGI::Cli::Lib->new(),
-        'Client object' );
-    count(2);
+    my ( $arg, $prms ) = @_;
+    if ($arg) {
+        $module = $arg;
+        use_ok($module);
+    }
+    $prms ||= {};
+    %$prms = (
+        configStorage => { type => 'File', dirName => 't' },
+        logLevel      => 'error',
+        cookieName    => 'lemonldap',
+        securedCookie => 0,
+        https         => 0,
+        logger => 'Lemonldap::NG::Common::Logger::Std',
+        %$prms
+    );
+    ok(
+        $client =
+          Lemonldap::NG::Handler::PSGI::Cli::Lib->new( { ini => $prms } ),
+        'Client object'
+    );
+    ok( $client->app, 'App object' ) or explain( $client, '->app...' );
+    count(3);
     open F, ">$file"
       or die $!;
     my $now = time;
@@ -43,6 +63,13 @@ sub client {
     return $client;
 }
 
+sub module {
+    if ( my $arg = shift ) {
+        $module = $arg;
+    }
+    return $module;
+}
+
 sub count {
     my $c = shift;
     $count += $c if ($c);
@@ -65,24 +92,18 @@ use Mouse;
 
 extends 'Lemonldap::NG::Common::PSGI::Cli::Lib';
 
+has ini => ( is => 'rw' );
+
 has app => (
     is      => 'ro',
     isa     => 'CodeRef',
     builder => sub {
-        return $module->run(
-            {
-                configStorage => { type => 'File', dirName => 't' },
-                logLevel      => 'warn',
-                cookieName    => 'lemonldap',
-                securedCookie => 0,
-                https         => 0,
-            }
-        );
+        return $module->run( $_[0]->{ini} );
     }
 );
 
 sub _get {
-    my ( $self, $path, $query, $host, $cookie ) = @_;
+    my ( $self, $path, $query, $host, $cookie, %custom ) = @_;
     $query //= '';
     $host ||= 'test1.example.com';
     return $self->app->(
@@ -103,7 +124,8 @@ sub _get {
               'Mozilla/5.0 (VAX-4000; rv:36.0) Gecko/20350101 Firefox',
             'REMOTE_ADDR' => '127.0.0.1',
             'HTTP_HOST'   => $host,
-            ( $cookie ? ( HTTP_COOKIE => $cookie ) : ( HTTP_COOKIE => '' ) )
+            ( $cookie ? ( HTTP_COOKIE => $cookie ) : ( HTTP_COOKIE => '' ) ),
+            %custom,
         }
     );
 }
